// 多张图片上传封装
function ImgListUp() {
  var _mindex = 0; // 定义上传开始的图片数
  var _upscu_number = 0; // 定义上传成功的图片数
  var imageFilter = api.require("imageFilter"); // 引入图片压缩模块
  var that = this;

  /**
     * 上传图片数组
     * @param  [Ojbect] param    //需要的上传的参数
               [Array] imglist   上传的图片数组     必传
               [String] service_url       上传图片的地址    必传
               [Number] height     压缩后图片的高度，默认为1000
               [String] url_name   图片地址字段名称  默认为path
     * @param  [Function] callback  图片全部上传完的回调函数  必传
     **/
  this.up = function (param, callback) {
    // 数据初始化
    var imglist = param.imglist;
    var service_url = param.service_url;
    var _height = param.height || 1000;
    var url_name = param.url_name || "path";

    // 校验图片数组的正确性,只有第一次执行的时候校验，后续递归不再校验
    if (_mindex == 0) {
      if (!checkImglist(imglist, url_name)) return;
    }

    // 正式开始逻辑
    // 1、先获取原图片大小，然后选择一个比例进行压缩
    getImgSizeByUrl(imglist[_mindex].path)
      .then(function (imgWidth) {
        var _url = imglist[_mindex].path;
        var _name = "qa_" + +new Date();
        var _scale = 1;

        if (imgWidth > _height) {
          _scale = (_height / imgWidth).toFixed(1);
        }
        //图片压缩
        return imgCompress(_url, _name, _scale);
      })
      .then(function (imgPath) {
        _mindex++;
        //递归执行
        if (_mindex <= imglist.length - 1) {
          that.up(param, callback);
        }

        return upToService(service_url, _mindex - 1, imgPath);
      })
      .then(function (res) {
        imglist[res.index] = {
          url: res.data,
        };

        _upscu_number++;
        if (_upscu_number >= imglist.length) {
          //回调结果数组
          callback(imglist);
        }
      })
      .catch(function (err) {
        _upscu_number++;
      });
  };

  /**
   * 校验传入的图片数组
   * @param  [Array]list   图片数组
   * @param  [String]url_name    图片地址字段名称
   **/
  function checkImglist(list, url_name) {
    if (!list instanceof Array) {
      alert("传入类型错误");
      return false;
    }

    if (list.length == 0) {
      alert("数组不能为空");
      return false;
    }

    for (var i = 0, len = list.length; i < len; i++) {
      if (!list[i].hasOwnProperty(url_name)) {
        alert("数组格式错误");
        return false;
      }
    }

    return true;
  }

  /**
   * 上传图片至服务器
   * @param  [String]url   上传的服务器地址
   * @param  [String]index   上传的第几张图片
   * @param  [String]path   图片的地址
   **/
  function upToService(url, index, path) {
    return new Promise(function (resolve, reject) {
      // console.log(new Date() + "开始上传图片：" + path);
      api.ajax(
        {
          url: url,
          method: "post",
          data: { files: { file: path } },
        },
        function (ret, err) {
          if (ret) {
            resolve({
              data: ret.data,
              index: index,
            });
          } else {
            reject(err);
          }
        }
      );
    });
  }

  // 根据URL获取图片的宽高
  function getImgSizeByUrl(url) {
    return new Promise(function (resolve, reject) {
      // console.log(new Date() + "开始获取图片宽高");
      var img = new Image(); // 创建对象
      img.src = url; // 改变图片的src

      var intervalId = setInterval(check, 40); // 定时执行获取宽高
      function check() {
        // 只要任何一方大于0,表示已经服务器已经返回宽高
        if (img.width > 0 || img.height > 0) {
          clearInterval(intervalId);
          resolve(img.width, img.height);
        }
      }
    });
  }

  /**
   * 压缩图片
   * @param  [String]url   压缩的图片地址
   * @param  [String]name     压缩图片的名称
   * @param  [Number]scale    压缩比例
   **/
  function imgCompress(url, name, scale) {
    return new Promise(function (resolve, reject) {
      // console.log(new Date() + "开始图片压缩，quality为0.5，scale为" + scale);
      //压缩图片
      imageFilter.compress(
        {
          img: url,
          quality: 0.5,
          scale: scale,
          save: {
            imgPath: "fs://compress",
            imgName: name + ".png",
          },
        },
        function (ret) {
          if (ret.status) {
            resolve(api.fsDir + "/compress/" + name + ".png");
          }
        }
      );
    });
  }
}
