var UIRongCloud;

// 引入模块
function UIRongCloud_require() {
  if (!UIRongCloud) {
    UIRongCloud = api.require("UIRongCloud");
  }
}

// 初始化
function UIRongCloud_init(token) {
  if (!UIRongCloud) {
    UIRongCloud_require();

    // 初始化融云 SDK，调用 connect 连接前务必保证调用此方法
    // 注：android init接口在APP启动之后只允许调用一次
    UIRongCloud.init(function (ret, err) {
      if (ret.status == "success") {
        console.log("融云初始化成功");
      } else {
        console.log("融云初始化失败" + err.code);
      }
    });
  }

  UIRongCloud_setConnectionStatusListener();
  UIRongCloud_setOnReceiveMessageListener();
  UIRongCloud_connect(token);

  // 延迟是为了解决有时候设置免打扰不成功问题
  setTimeout(function () {
    UIRongCloud_addNeedAvatarListener();
    UIRongCloud_disableLocalNotification();
    UIRongCloud_setNotificationQuietHours();
  }, 1000);
}

// 注销登录(不再接收 Push 消息)
function UIRongCloud_logout() {
  if (!UIRongCloud) {
    return;
  }

  UIRongCloud.logout(function (ret, err) {
    if (ret.status == "success") {
      console.log("融云注销成功");
    } else {
      console.log("融云注销失败" + err.code);
    }
  });
}

// 连接融云 IM 服务器，进行后续各种方法操作前务必要先调用此方法
function UIRongCloud_connect(token) {
  UIRongCloud_require();
  UIRongCloud.connect(
    {
      token: token,
    },
    function (ret, err) {
      if (ret.status == "success") {
        console.log("融云连接成功" + (ret.result ? ret.result.userId : ""));
      } else {
        console.log("融云连接失败" + err.code);
      }
    }
  );
}

// 设置连接状态变化的监听器，请在调用 init 方法之后，调用 connect 方法之前设置
function UIRongCloud_setConnectionStatusListener() {
  UIRongCloud_require();
  UIRongCloud.setConnectionStatusListener(function (ret, err) {
    var status = ret.result.connectionStatus;
    api.sendEvent({
      name: "rongCloud_connectionStatus",
      extra: {
        status: status,
      },
    });
    // console.log("融云连接状态" + status);
  });
}

// 添加需要设置头像的时刻的监听
function UIRongCloud_addNeedAvatarListener() {
  UIRongCloud_require();
  UIRongCloud.addNeedAvatarListener(function (ret) {
    var userId = ret.userId;
    zk.api.getRongUserInfo(userId).then(function (res) {
      UIRongCloud_setUserAvatar(userId, res.name, res.portrait);
    });
  });
}

// 设置用户头像
function UIRongCloud_setUserAvatar(userId, nickName, avatarUrl) {
  UIRongCloud_require();
  var params = {
    userId: userId,
    nickName: nickName,
    avatarUrl: avatarUrl,
  };
  UIRongCloud.setUserAvatar(params);
}

// 设置接收消息的监听器，请在调用 init 方法之后，调用 connect 方法之前设置
function UIRongCloud_setOnReceiveMessageListener() {
  UIRongCloud_require();
  UIRongCloud.setOnReceiveMessageListener(function (ret, err) {
    var message = ret.result.message;
    api.sendEvent({
      name: "rongCloud_newMessage",
      extra: {
        message: message,
      },
    });
    // console.log("融云新消息" + JSON.stringify(message));
  });
}

// 设置本地消息不提示
function UIRongCloud_disableLocalNotification() {
  UIRongCloud_require();
  UIRongCloud.disableLocalNotification(function (ret, err) {
    console.log("设置本地消息不提示" + ret.status);
  });
}

// 设置消息通知免打扰时间
function UIRongCloud_setNotificationQuietHours() {
  UIRongCloud_require();
  UIRongCloud.setNotificationQuietHours(
    {
      startTime: "22:00:00",
      spanMinutes: 1439,
    },
    function (ret, err) {
      console.log("设置消息通知免打扰时间" + ret.status);
    }
  );
}

// 获取所有未读消息数
function UIRongCloud_getTotalUnreadCount() {
  return new Promise(function (resolve, reject) {
    UIRongCloud_require();
    UIRongCloud.getTotalUnreadCount(function (ret, err) {
      if (ret.status == "success") {
        resolve(ret.result);
      }
    });
  });
}

// 获取来自某用户（某会话）的未读消息数
function UIRongCloud_getUnreadCount(type, targetId) {
  return new Promise(function (resolve, reject) {
    UIRongCloud_require();
    UIRongCloud.getUnreadCount(
      {
        conversationType: type,
        targetId: targetId,
      },
      function (ret, err) {
        if (ret.status == "success") {
          resolve(ret.result);
        }
      }
    );
  });
}

// 获取连接状态
function UIRongCloud_getConnectionStatus(callback) {
  UIRongCloud_require();
  UIRongCloud.getConnectionStatus(function (ret, err) {
    if (ret.status === "success") {
      if (typeof callback === "function") {
        var status = ret.result.connectionStatus;
        callback(status);
      }
    }
  });
}

/**
 * 分页获取会话列表
 * @param {Number} startTime 会话的时间戳（获取这个时间戳之前的会话列表，0表示从最新开始获取）
 */
function UIRongCloud_getConversationListByCount(startTime) {
  return new Promise(function (resolve, reject) {
    UIRongCloud_require();
    UIRongCloud.getConversationListByCount(
      {
        typeList: ["private", "group"],
        count: 10,
        startTime: startTime || 0,
      },
      function (ret, err) {
        if (ret.status === "success") {
          resolve(ret.result);
        }
      }
    );
  });
}

// 获取某一会话信息
function UIRongCloud_getConversation(targetId, type) {
  return new Promise(function (resolve, reject) {
    UIRongCloud_require();
    UIRongCloud.getConversation(
      {
        conversationType: type,
        targetId: targetId,
      },
      function (ret, err) {
        if (ret.status === "success") {
          resolve(ret.result);
        }
      }
    );
  });
}

// 从会话列表中移除某一会话，但是不删除会话内的消息
function UIRongCloud_removeConversation(targetId, type, callback) {
  UIRongCloud_require();
  UIRongCloud.removeConversation(
    {
      conversationType: type,
      targetId: targetId,
    },
    function (ret, err) {
      if (ret.status === "success" && typeof callback === "function") {
        callback();
      } else {
        console.log(JSON.stringify(err));
      }
    }
  );
}

// 打开会话页面
function UIRongCloud_openConversation(targetId, type, title, callback) {
  UIRongCloud_require();
  UIRongCloud.openConversation(
    {
      targetId: targetId,
      conversationType: type,
      title: title,
      navigationBar: {
        titleColor: "#fff",
        bgColor: "#0099ff",
        backImage: "widget://image/icon-arrow-left@white.png",
        backImageSize: 24,
      },
    },
    callback
  );
}

// 配置聊天页面按钮
// 必须在调用openConversation接口之前调用本接口才能有效
function UIRongCloud_configChatButtons() {
  UIRongCloud_require();
  UIRongCloud.configChatButtons({
    pluginItems: ["file", "image", "emoji"],
  });
}

// 配置聊天相关功能
function UIRongCloud_configChat() {
  UIRongCloud_require();
  UIRongCloud.configChat({
    messageRecall: true, // 是否开启撤销刚发送消息的功能
    typingStatus: true, // 是否显示对方输入状态
  });
}

// 配置群聊相关功能
// 需在每次openConversation接口打开群聊页面之前调用
function UIRongCloud_configGroupChat() {
  UIRongCloud_require();
  UIRongCloud.configGroupChat({
    messageMentioned: false, // 是否开启@功能
  });
}
