var wxPlus = null; // 模块

/**
 * 是否安装微信
 * @param {Function} callback 回调函数
 * @param {Boolean} alert 未安装微信下是否提示
 */
function wxPlus_isInstalled(callback, alert) {
  wxPlus = api.require("wxPlus");
  wxPlus.isInstalled(function (ret, err) {
    if (ret.installed && typeof callback === "function") {
      callback();
    } else if (typeof alert === "undefined" ? true : alert) {
      api.alert({ msg: "当前设备未安装微信客户端" });
    }
  });
}

/**
 * 登录授权
 * @param {Function} callback 回调函数
 */
function wxPlus_auth(callback) {
  wxPlus_isInstalled(function () {
    wxPlus.auth({}, function (ret, err) {
      if (ret.status && typeof callback === "function") {
        callback(ret.code);
      }
    });
  });
}

/**
 * 获取授权 accessToken
 * @param {Function} callback 回调函数
 */
function wxPlus_getToken(callback) {
  wxPlus_auth(function (code) {
    wxPlus.getToken(
      {
        code: code,
      },
      function (ret, err) {
        if (ret.status && typeof callback === "function") {
          callback(ret);
        }
      }
    );
  });
}

/**
 * 获取用户信息
 * @param {Function} callback 回调函数
 */
function wxPlus_getUserInfo(callback) {
  wxPlus_getToken(function (res) {
    wxPlus.getUserInfo(
      {
        accessToken: res.accessToken,
        openId: res.openId,
      },
      function (ret, err) {
        if (ret.status && typeof callback === "function") {
          callback(ret);
        }
      }
    );
  });
}

/**
 * 拉起小程序
 * @param {String} path 拉起小程序页面的可带参路径，不填默认拉起小程序首页
 */
function wxPlus_launchMiniProgram(path) {
  wxPlus_isInstalled(function () {
    wxPlus.launchMiniProgram({
      miniProgramType: "release",
      userName: "gh_842c06e5db94",
      path: path,
    });
  });
}

/**
 * 一键订阅
 * @param {Function} callback 回调函数
 */
function wxPlus_subscribeMsg(callback) {
  wxPlus_isInstalled(function () {
    wxPlus.subscribeMsg(
      {
        apiKey: "wx7eefa4b1d25f6c96",
        scene: 1,
        templateId: "cXQD0b_9_-uq2sVms20QO_eQwlzzUjBo-wF8pbUF9dM",
      },
      function (ret, err) {
        if (ret.eventType == "back" && typeof callback === "function") {
          callback(ret);
        }
      }
    );
  });
}
