/**
 * 所有网络请问接口(使用之前需要先引入 bluebird.min.js 和 zk.js)
 */

zk.api = {
  /**
   * 短信前置-获取图片验证码
   * @param {String} phone 手机号码
   */
  getImageCode: function (phone) {
    return zk.request({
      url: "sms/getImageCode",
      data: {
        phone: phone,
      },
    });
  },

  /**
   * 获取短信验证码
   * @param {String} phone 手机号码
   * @param {Number} imageCode 4位数字的图片验证码
   */
  sendSmscode: function (phone, imageCode) {
    return zk.request({
      url: "sms/sendSms",
      method: "post",
      data: {
        phone: phone,
        imageCode: imageCode,
        type: 31,
      },
    });
  },

  /**
   * 短信验证码登录
   * @param {String} phone 手机号码
   * @param {Number} smsCode 6位数字的短信验证码
   */
  smscodeLogin: function (phone, smsCode) {
    return zk.request({
      url: "login/sms",
      method: "post",
      data: {
        phone: phone,
        smsCode: smsCode,
        type: 31,
      },
    });
  },

  /**
   * 账号密码登录
   * @param {String} phone 账号
   * @param {String} password 密码
   */
  passwordLogin: function (phone, password) {
    return zk.request({
      url: "login/login",
      method: "post",
      data: {
        phone: phone,
        password: password,
      },
    });
  },

  // 自动登录
  autoLogin: function () {
    return zk.request({
      url: "login/autoLogin",
      method: "post",
    });
  },

  /**
   * 微信登录
   * @param {String} openid 微信授权用户唯一标识
   * @param {String} accessToken 微信接口调用凭证
   */
  weChatLogin: function (openid, accessToken) {
    return zk.request({
      url: "login/wechatLogin",
      data: {
        openid: openid,
        accessToken: accessToken,
      },
    });
  },

  /**
   * 首次微信登录，微信绑定手机号码
   * @param {String} phone
   * @param {String} unionid
   * @param {Number} smsCode
   */
  wechatBind: function (phone, unionid, smsCode) {
    return zk.request({
      url: "login/bindWechat",
      method: "post",
      data: {
        phone: phone,
        unionid: unionid,
        smsCode: smsCode,
        type: 4,
      },
    });
  },

  /**
   * 验证短信验证码
   * @param {String} phone 手机号码
   * @param {Number} smsCode 6位数字的短信验证码
   */
  verifySmscode: function (phone, smsCode) {
    return zk.request({
      url: "sms/userValid",
      method: "post",
      data: {
        phone: phone,
        smsCode: smsCode,
      },
    });
  },

  /**
   * 重置密码
   * @param {String} phone 手机号码
   * @param {String} password 密码
   */
  resetPassword: function (phone, password) {
    return zk.request({
      url: "login/resetPwd",
      method: "post",
      data: {
        phone: phone,
        password: password,
      },
    });
  },

  /**
   * 获取 Banner
   * @param {Number} professionId 职称ID
   */
  getBanners: function (professionId) {
    return zk.request({
      url: "main/banners",
      data: {
        professionId: professionId,
        type: 1,
      },
    });
  },

  /**
   * 获取公开课列表
   * @param {Number} professionId 职称ID
   * @param {Number} page 当前页码
   */
  getOpenClassList: function (professionId, page) {
    return zk.request({
      url: "main/findLive/" + professionId + "/" + (page || 1),
    });
  },

  /**
   * 公开课预约
   * @param {Number} professionId 职称Id
   * @param {Number} status 预约或者取消预约标识：1、预约；2、取消预约
   * @param {Number} liveDetailId 直播详细id
   */
  reserveOpenclass: function (professionId, status, liveDetailId) {
    return zk.request({
      url: "https://cj.tibaitong.com/api/push/prepareCourse",
      data: {
        professionId: professionId,
        status: status,
        liveDetailId: liveDetailId,
      },
    });
  },

  /**
   * 修改昵称
   * @param {String} nickname 要修改的昵称
   */
  changeNick: function (nickname) {
    return zk.request({
      url: "user/changeNick",
      method: "post",
      data: {
        nick: nickname,
      },
    });
  },

  /**
   * 修改个性签名
   * @param {String} signature 要修改的签名
   */
  changeSignature: function (signature) {
    return zk.request({
      url: "user/changeSignature",
      method: "post",
      data: {
        signature: signature,
      },
    });
  },

  /**
   * 修改密码
   * @param {String} oldPwd 原密码
   * @param {String} newPwd 新密码
   */
  changePassword: function (oldPwd, newPwd) {
    return zk.request({
      url: "user/changePassword",
      data: {
        oldPwd: oldPwd,
        newPwd: newPwd,
      },
    });
  },

  /**
   * 切换职称
   * @param {Number} professionId 职称Id
   */
  changeProfession: function (professionId) {
    return zk.request({
      url: "login/changeProfession",
      data: {
        professionId: professionId,
      },
    });
  },

  /**
   * 切换课程
   * @param {Number} courseId 课程Id
   */
  changeCourse: function (courseId) {
    return zk.request({
      url: "login/changeCourse",
      data: {
        courseId: courseId,
      },
    });
  },

  /**
   * 获取错题打印是否有权限，和是否开放
   * @param {Number} courseId 课程Id
   */
  getErrorAuth: function (courseId) {
    return zk.request({
      url: "section/getErrorPrintInfo",
      data: {
        courseId: courseId,
      },
    });
  },

  /**
   * 错题打印-错题点评
   * @param {Number} professionId 职称Id
   * @param {Number} courseId 课程Id
   */
  getErrorComment: function (professionId, courseId) {
    return zk.request({
      url: "section/getErrorComment",
      data: {
        professionId: professionId,
        courseId: courseId,
      },
    });
  },

  /**
   * 错题打印-错题章节
   * @param {Number} courseId 课程Id
   */
  getErrorSection: function (courseId) {
    return zk.request({
      url: "https://cj.tibaitong.com/api/section/errorSection",
      data: {
        courseId: courseId,
      },
    });
  },

  /**
   * 获取题库类型列表
   * @param {Number} courseId 课程Id
   */
  getTikuType: function (courseId) {
    return zk.request({
      url: "section/findSectionType",
      data: {
        courseId: courseId,
      },
    });
  },

  /**
   * 获取历年真题列表
   * @param {Number} courseId 课程Id
   */
  // getRealExams: function (courseId) {
  //   return zk.request({
  //     url: "https://cj.tibaitong.com/api/section/querySection",
  //     data: {
  //       courseId: courseId,
  //       sectionType: 8
  //     },
  //   });
  // },

  /**
   * 导出试题
   * @param {Number} sectionId 章节id
   * @param {Number} exportType 导出类型
   */
  exportQuestion: function (sectionId, exportType) {
    return zk.request({
      url: "export/question",
      data: {
        sectionId: sectionId,
        exportType: exportType,
      },
    });
  },

  /**
   * 判断题库章节类型权限
   * @param {Number} courseId 课程id
   * @param {Number} sectionType 章节类型
   */
  checkTikuAuth: function (courseId, sectionType) {
    return zk.request({
      url: "course/isHasAuthOfSection",
      data: {
        courseId: courseId,
        type: sectionType,
      },
    });
  },

  /**
   * 提交用户的极光注册id
   * @param {Number} userId  用户标识
   * @param {String} registrationId jpush的唯一性id
   */
  updatePushDevice: function (userId, registrationId) {
    return zk.request({
      url: "https://cj.tibaitong.com/api/push/updateDevice",
      method: "post",
      data: {
        type: api.systemType === "ios" ? 2 : 1, // 设备类型：1、android；2、ios；
        appType: 1, // APP类型：1、卓考网校；2、救命稻草
        userId: userId,
        jpushId: registrationId,
        deviceNo: api.deviceId,
      },
    });
  },

  /**
   * 是否是聊天用户
   * @param {Number} userId 用户ID
   */
  isImUser: function (userId) {
    return zk.request({
      url: "im/user/findIsImUser/" + userId,
    });
  },

  /**
   * 获取用户的融云信息
   * @param {Number} userId 用户ID
   */
  getUserRongInfo: function (userId) {
    return zk.request({
      url: "im/user/findIuserRongIdAndToken/" + userId,
    });
  },

  /**
   * 获取会话列表数据
   * @param {String} userIds 用户ID组
   * @param {String} groupIds 群ID组
   * @param {Number} userId 用户ID
   */
  getConversationData: function (userIds, groupIds, userId) {
    return zk.request({
      url: "im/user/findConversationData2",
      method: "post",
      data: {
        userRongIds: userIds,
        groupIds: groupIds,
        userId: userId,
      },
    });
  },

  /**
   * 获取融云用户信息
   * @param {Number} rongId
   */
  getRongUserInfo: function (rongId) {
    return zk.request({
      url: "im/user/findIuserInfo/" + rongId,
    });
  },

  /**
   * 获取融云群聊信息
   * @param {Number} groupId
   */
  getRongGroupInfo: function (groupId) {
    return zk.request({
      url: "im/group/getGroupInfo/" + groupId,
    });
  },

  /**
   * 获取融云群
   * @param {Number} type 群类型：3为死党组，其他为班级群
   */
  getRongGroupList: function (type) {
    return zk.request({
      url: "im/group/getGroupList",
      data: {
        userRole: type || 1,
      },
    });
  },

  /**
   * 获取群成员列表
   */
  getRongGroupMembers: function (groupId) {
    return zk.request({
      url: "im/group/getAllGroupMembers/" + groupId,
    });
  },

  // 获取融云老师列表
  getRongTeachers: function () {
    return zk.request({
      url: "im/relation/getTeacherList",
    });
  },

  /**
   * 获取今日直播
   */
  getTodayLive: function (professionId) {
    return zk.request({
      url: "video/todayLive?courseType=" + professionId,
    });
  },

  /**
   * 获取我的课表
   */
  getMySchedule: function (professionId, type) {
    return zk.request({
      url:
        "courseArrange/courseArrangeList?professionId=" +
        professionId +
        "&type=" +
        (type || 0),
    });
  },

  /**
   * 获取语音章节列表
   */
  getVoiceChapterList: function (professionId, courseId) {
    return zk.request({
      url: "courseArrange/voiceChapterList",
      data: {
        professionId: professionId,
        courseId: courseId,
      },
    });
  },

  /**
   * 根据条件搜索好友或群组
   */
  searchRongUserAndGroup: function (userId, keyword) {
    return zk.request({
      url: "imUser/searchByKey",
      data: {
        userId: userId,
        key: keyword,
      },
    });
  },

  // 是否签署协议
  getSignStatus: function (courseId) {
    return zk.request({
      url: "main/getSignInfo",
      data: {
        courseId: courseId,
      },
    });
  },

  /**
   * 获取用户分班状态
   * @param {Number} professionId 职称ID
   */
  getAssignStatus: function (professionId) {
    return zk.request({
      url: "class/userAssignmentStatus",
      data: {
        professionId: professionId,
      },
    });
  },

  /**
   * 获取分班调查表信息
   * @param {Number} professionId 职称ID
   */
  getAssignSurveyInfo: function (professionId) {
    return zk.request({
      url: "class/courseTime",
      data: {
        professionId: professionId,
      },
    });
  },

  // 保存用户分班调查信息
  saveAssignSurveyInfo: function (data) {
    return zk.request({
      url: "class/insert",
      method: "post",
      data: data,
    });
  },

  // /**
  //  * 获取直播列表
  //  * @param {Number} courseId 课程id
  //  */
  // getLiveList: function (courseId) {
  //   return zk.request({
  //     url: "live/findLiveList/" + courseId,
  //   });
  // },

  /**
   * 获取考点必刷列表
   * @param {Number} courseId 课程id
   */
  getChapterList: function (courseId) {
    return zk.request({
      url: "courseChapter/getChapter",
      data: {
        courseId: courseId,
      }
    });
  },

  /**
   * 获取直播列表
   * @param {Number} courseId 课程id
   */
  getLiveList: function (courseId) {
    return zk.request({
      url: "learningTasks/findLearningTasks/" + courseId,
    });
  },

  /**
   * 判断视频类型权限
   * @param {Number} courseId 课程id
   * @param {Number} videoType 视频类型
   */
  checkVideoAuth: function (courseId, videoType) {
    return zk.request({
      url: "course/isHasAuthOfVideo",
      data: {
        courseId: courseId,
        type: videoType,
      },
    });
  },

  /**
   * 检查直播权限
   * @param {Number} liveDetailId 直播详细id
   */
  checkLiveAuth: function (liveDetailId) {
    return zk.request({
      url: "live/checkLiveAuth/" + liveDetailId,
    });
  },

  /**
   * 获取视频类型列表
   * @param {Number} courseId 课程ID
   */
  getVideoType: function (courseId) {
    return zk.request({
      url: "videoPlus/findVideoYearAndType",
      data: {
        courseId: courseId,
      },
    });
  },

  /**
   * 获取视频类型标题
   * @param {String} videoJoint 视频关联ID
   */
  getVideoTypeName: function (videoJoint) {
    return zk.request({
      url: "videoBase/getVideoBaseName",
      data: {
        videoJoint: videoJoint,
      },
    });
  },

  /**
   * 获取视频老师列表
   * @param {String} videoJoint 视频关联ID
   */
  getVideoTeachers: function (videoJoint) {
    return zk.request({
      url: "videoPlus/findTeacherByJoint",
      data: {
        videoJoint: videoJoint,
      },
    });
  },

  /**
   * 获取上次播放的视频
   * @param {String} videoJoint 视频关联ID
   * @param {Number} teacherId 老师Id
   */
  getLastPlay: function (videoJoint, teacherId) {
    return zk.request({
      url: "videoPlus/getLatestWatched",
      data: {
        videoJoint: videoJoint,
        teacherId: teacherId,
      },
    });
  },

  /**
   * 获取视频列表
   * @param {String} videoJoint 视频关联ID
   * @param {Number} teacherId 老师Id
   */
  getPlaylist: function (videoJoint, teacherId) {
    return zk.request({
      url: "videoPlus/findVideoList",
      data: {
        videoJoint: videoJoint,
        teacherId: teacherId,
      },
    });
  },

  /**
   * 获取讲义列表
   * @param {String} videoJoint 视频关联ID
   * @param {Number} teacherId 老师Id
   */
  getVideoHandoutList: function (videoJoint, teacherId) {
    return zk.request({
      url: "videoHandout/findByJoint",
      data: {
        videoJoint: videoJoint,
        teacherId: teacherId,
      },
    });
  },

  /**
   * 记录用户视频下载记录
   * @param {Number} videoId 视频id
   */
  saveUserVideo(videoId) {
    return zk.request({
      url: "/videoPlus/saveUserVideo",
      method: "post",
      data: {
        videoId,
      },
    });
  },

  /**
   * 获取某一视频详细信息
   * @param {Number} videoId 视频id
   */
  getVideoDetail: function (videoId) {
    return zk.request({
      url: "videoPlus/getDetail",
      data: {
        videoId: videoId,
      },
    });
  },

  /**
   * 获取直播回放视频详细
   * @param {Number} liveDetailId 直播详细id
   */
  getReplayDetail: function (liveDetailId) {
    return zk.request({
      url: "live/getPlayback/" + liveDetailId,
    });
  },

  /**
   * 保存视频观看进度
   * @param {Number} videoId 视频id
   * @param {String} watchDuration 视频观看时长
   */
  savePlayProgress: function (videoId, watchDuration) {
    return zk.request({
      url: "videoPlus/updateWatched",
      method: "post",
      data: {
        videoId: videoId,
        watchDuration: watchDuration,
      },
    });
  },

  /**
   * 保存直播回放观看进度
   * @param {Number} liveDetailId 直播详细id
   * @param {String} watchDuration 视频观看时长
   */
  saveReplayProgress: function (liveDetailId, watchDuration) {
    return zk.request({
      url: "live/updateWatched",
      method: "post",
      data: {
        liveDetailId: liveDetailId,
        watchDuration: watchDuration,
      },
    });
  },

  /**
   * 获取新闻资讯
   * @param {Number} professionId 职称id
   */
  getNews: function (professionId) {
    return zk.request({
      url: "news/findNewsByType/32",
      data: {
        professionId: professionId,
      },
    });
  },

  // 获取所有分班
  getAllClass: function () {
    return zk.request({
      url: "class/findClassAll",
    });
  },

  /**
   * 签署协议
   * @param {String} userName 姓名
   */
  sign: function (userName) {
    return zk.request({
      url: "main/signing",
      method: "post",
      data: {
        userName: userName,
      },
    });
  },

  // 获取我的专属老师
  getMyTeacher: function () {
    return zk.request({
      url: "user/getMyTeacher",
    });
  },

  // 获取用户绑定的微信账号信息
  getUserWechatInfo: function () {
    return zk.request({
      url: "user/getUserWechat",
    });
  },

  // 解绑微信
  unbindWechat: function () {
    return zk.request({
      url: "user/unbindUserWechat",
    });
  },

  /**
   * 绑定微信
   * @param {Object} user 微信获取的用户信息
   */
  bindWechat: function (user) {
    return zk.request({
      url: "user/bindUserWechat",
      method: "post",
      data: user,
    });
  },

  /**
   * 发送微信订阅消息
   * @param {Object} data POST数据
   */
  sendSubscribeMsg: function (data) {
    return zk.request({
      url: "wechat/sendApiMessage",
      method: "post",
      data: data,
    });
  },

  /**
   * 上传日志
   * @param {String} text 文本
   */
  uploadLog: function (text) {
    var log = typeof text === "string" ? text : JSON.stringify(text);
    return zk.request({
      url: "https://cbt.tibaitong.com/main/printLog?log=" + log,
    });
  },
};
