(function (window) {
  var baseUrl = "https://cbt.tibaitong.com/";

  /***************************************************
   *                   本地存储                       *
   ***************************************************/

  var storage = {
    get: function (key) {
      var value = api.getPrefs({ sync: true, key: key }) || "";

      // 如果JSON字符串无法解析，直接返回
      try {
        return JSON.parse(value);
      } catch (e) {
        return value;
      }
    },

    set: function (key, value) {
      api.setPrefs({
        key: key,
        value: JSON.stringify(value),
      });
    },

    del: function (key) {
      api.removePrefs({
        key: key,
      });
    },
  };

  // 设置 token
  function setToken(token) {
    return storage.set("token", token);
  }

  // 获取 token
  function getToken() {
    return storage.get("token");
  }

  // 判断当前是否登录
  function isLogin() {
    var token = getToken();
    return token ? true : false;
  }

  // 设置 userId
  function setUserId(userId) {
    return storage.set("userId", userId);
  }

  // 获取 userId
  function getUserId() {
    return storage.get("userId");
  }

  // 设置 unionid
  function setUnionid(unionid) {
    return storage.set("unionid", unionid);
  }

  // 获取 unionid
  function getUnionid() {
    return storage.get("unionid");
  }

  // 设置当前职称Id
  function setProfessionId(professionId) {
    return storage.set("professionId", professionId);
  }

  // 获取当前职称Id
  function getProfessionId() {
    return storage.get("professionId");
  }

  // 设置当前职称名字
  function setProfessionName(professionName) {
    return storage.set("professionName", professionName);
  }

  // 获取当前职称名字
  function getProfessionName() {
    return storage.get("professionName");
  }

  // 设置当前课程Id
  function setCourseId(courseId) {
    return storage.set("courseId", courseId);
  }

  // 获取当前课程Id
  function getCourseId() {
    return storage.get("courseId");
  }

  // 设置当前手机号
  function setPhoneNumber(phoneNumber) {
    return storage.set("phoneNumber", phoneNumber);
  }

  // 获取当前手机号
  function getPhoneNumber() {
    return storage.get("phoneNumber");
  }

  // 设置用户昵称
  function setNickname(nickname) {
    return storage.set("nick", nickname);
  }

  // 获取用户昵称
  function getNickname() {
    return storage.get("nick");
  }

  // 设置用户签名
  function setSignature(signature) {
    return storage.set("signature", signature);
  }

  // 获取用户签名
  function getSignature() {
    return storage.get("signature");
  }

  // 设置用户头像
  function setAvatar(imageSrc) {
    return storage.set("photo", imageSrc);
  }

  // 获取用户头像
  function getAvatar() {
    return storage.get("photo");
  }

  // 设置职称权限列表
  function setKeyStoreMap(keystoreMap) {
    return storage.set("keystoreMap", keystoreMap); 
  }
  // 获取职称权限列表
  function getKeyStoreMap() {
    return storage.get("keystoreMap"); 
  }
  /**
   * 保存用户信息
   * @param {Object} user 用户信息
   */
  function saveUserInfo(user) {
    setToken(user.token);
    setUserId(user.userId);
    setUnionid(user.unionid);
    setPhoneNumber(user.phone);
    setNickname(user.nick);
    setSignature(user.signature);
    setAvatar(user.photo);
    setKeyStoreMap(user.keystoreMap)
  }

  // 设置预约私教权限
  function setHasService(isHas) {
    storage.set("serviceAuth", isHas);
  }

  // 获取预约私教权限
  function getHasService() {
    var value = storage.get("serviceAuth");
    return typeof value === "boolean" ? value : false;
  }

  // 是否首次启动APP
  function isFirstLaunch() {
    var value = storage.get("firstLaunch");
    return typeof value === "boolean" ? value : true;
  }

  // 设置为非首次启动
  function setNonFirstLaunch() {
    storage.set("firstLaunch", false);
  }

  // 设置融云Token
  function setRongToken(token) {
    return storage.set("rongToken", token);
  }

  // 获取融云Token
  function getRongToken() {
    return storage.get("rongToken");
  }

  // 是否具有班级服务
  function hasClassService() {
    return true;
  }

  /***************************************************
   *                   网络请求                       *
   ***************************************************/

  /**
   * 封装的请求(使用之前，要引入 bluebird.min.js)
   * @param {String} url 请求地址
   * @param {String} method 异步请求方法类型
   * @param {Object} data POST 数据，method 为 get 时不传
   */
  function request(params) {
    var url = params.url.indexOf("http") == 0 ? params.url : baseUrl + params.url;
    var method = params.method || "get";
    var data = params.data || {};
    var token = getToken();

    return new Promise(function (resolve, reject) {
      api.ajax(
        {
          url: url,
          method: method,
          headers: {
            "Content-Type": "application/json;charset=utf-8",
            "ZK-TOKEN": token,
            'APP-TYPE': 1
          },
          timeout: 5,
          data: {
            body: data,
          },
        },
        function (ret, err) {
          if (ret) {
            if (ret.code === 200) {
              resolve(ret.data);
            } else if (ret.code === 600) {
              loginExpired();
            } else if (ret.msg) {
              toast(ret.msg);
            }
            reject(ret);
          } else {
            toast("发生错误,请稍后再试");
            reject(err);
          }
        }
      );
    });
  }

  /***************************************************
   *                   登录退出                       *
   ***************************************************/

  /**
   * 登录成功
   * @param {Object} user 用户信息
   */
  function loginSuccess(user) {
    toast("登录成功");
    saveUserInfo(user);

    request({
      url: "call/security",
    }).then(function (res) {
      if (res != null && res.length > 0) {
        setHasService(true);
      } else {
        setHasService(false);
      }
    }).finally(function () {
      // 发送用户登录事件
      api.sendEvent({
        name: "login",
        extra: user,
      });
    });

    closeToHome();
  }

  /**
   * 登录过期处理逻辑
   * @param {String} message 提示
   */
  function loginExpired(message) {
    clearUserInfo();

    // 发送退出事件
    api.sendEvent({
      name: "logout",
    });

    api.execScript({
      name: "home",
      script: "closeToAndLogin('" + (message || "登录过期，请重新登录") + "')",
    });
  }

  /**
   * 退出登录【新增用于注销结束处理】
   */
  function exit() {
    api.sendEvent({
      name: "logout",
    });
    clearUserInfo();
    closeToHome()
  }

  /**
   * 清理用户信息
   */
  function clearUserInfo() {
    storage.del("token");
    storage.del("rongToken");
  }

  /**
   * 关闭到主页
   */
  function closeToHome() {
    api.closeToWin({
      name: "home",
    });
  }

  /***************************************************
   *                   权限判断                       *
   ***************************************************/

  var PERMISSIONNAME = {
    camera: "相机", // 相机/拍照/录像
    contacts: "联系人", // 联系人读取/写入
    microphone: "麦克风", // 使用麦克风录制音频
    photos: "访问相册", // 访问相册|本地存储空间。Android上等同storage权限
    location: "定位", // 定位
    locationAlways: "后台定位", // 后台定位，只支持iOS
    notification: "状态栏通知", // 状态栏通知
    calendar: "日历", // 日历读取/写入。只支持Android
    phone: "电话", // 直接拨打电话/获取手机号码|IMEI。只支持Android
    sensor: "传感器", // 传感器.只支持Android
    sms: "短信", // 读取短信/后台发送短信。只支持Android
    storage: "存储", // 读取/写入|相册|多媒体|本地存储空间。只支持Android
  };

  /**
   * 判断是否拥有权限
   * @param {Array} perms 权限列表
   */
  function hasPermission(perms) {
    return api.hasPermission({
      list: perms,
    });
  }

  /**
   * 向系统请求权限
   * @param {Array} perms 权限列表
   */
  function requestPermission(perms) {
    api.requestPermission({
      list: perms,
      code: 1,
    });
  }

  /**
   * 确认权限(无权限提示获取)
   * @param {Array} perms 权限列表
   */
  function confirmPermission(perms) {
    var resultList = hasPermission(perms);

    // 获取需要请求的权限列表
    var requestList = [];
    resultList.forEach(function (item, index) {
      if (!item || !item.granted) {
        requestList.push(perms[index]);
      }
    });

    // 如果拥有全部权限
    if (requestList.length === 0) {
      return true;
    }

    // 否则，提示请求权限
    var str = "";
    requestList.forEach(function (per) {
      str += PERMISSIONNAME[per] + "、";
    });
    str = str.slice(0, str.length - 1);

    api.confirm(
      {
        title: "提醒",
        msg: "使用相关功能，用于拍摄和存储图片等场景,需要获取" + str + "权限，是否前往设置？",
        buttons: ["去设置", "取消"],
      },
      function (ret) {
        if (ret.buttonIndex === 1) {
          requestPermission(perms);
        }
      }
    );
    return false;
  }

  /***************************************************
   *                   界面UI                       *
   ***************************************************/

  /**
   * 显示加载
   * @param {String} title 标题
   */
  function showLoading(title) {
    api.showProgress({
      title: title || "加载中",
      text: "请稍候...",
    });
  }

  /**
   * 隐藏加载
   */
  function hideLoading() {
    api.hideProgress();
  }

  /**
   * 提示
   * @param {String} msg 提示信息
   */
  function toast(msg) {
    api.toast({
      msg: msg,
      global: true,
    });
  }

  /***************************************************
   *                   工具辅助                       *
   ***************************************************/

  /**
   * 控制台打印日志,主要用于开发调试
   */
  function log(msg) {
    if (typeof msg === "object") {
      console.log(JSON.stringify(msg));
    } else {
      console.log(msg);
    }
  }

  /**
   * 打开外部网页
   * @param {String} url 网页地址
   * @param {String} title 网页标题（不传时，不显示导航栏）
   */
  function webview(url, title) {
    api.openTabLayout({
      name: "webview",
      url: "widget://html/webview.html",
      title: title,
      navigationBar: {},
      hideNavigationBar: !title,
      pageParam: {
        url: url,
        title: title,
      },
      reload: true,
    });
  }

  /**
   * 格式化文件大小, 输出成带单位的字符串
   * @param {Number} size 文件大小
   */
  function formatFileSize(size) {
    var units = ["B", "K", "M", "G", "TB"];
    for (var i = 0; size > 1024; i++) {
      size /= 1024;
    }
    return size.toFixed(1) + units[i];
  }

  /**
   * 清理APP缓存
   *  @param {Function} callback 回调函数
   */
  function clearAppCache(callback) {
    api.clearCache(callback);
  }

  /**
   * 打开浏览器
   * @param {String} url 网址
   */
  function openBrowser(url) {
    if (api.systemType === 'ios') {
      api.openApp({
        iosUrl: url,
      });
    } else {
      var jumpbrowser = api.require('jumpbrowser')
      var param = { Url: url };
      jumpbrowser.jumpBrowser(param);
    }
  }

  // 打开微信
  function openWeChat() {
    api.openApp({
      androidPkg: "com.tencent.mm",
      uri: "weixin://",
      iosUrl: "weixin://",
    });
  }

  /***************************************************
   *                   公共页面                       *
   ***************************************************/

  // 打开登录页面
  function openLogin() {
    api.openTabLayout({
      name: "login",
      url: "widget://html/login/index.html",
      navigationBar: {},
    });
  }

  // 打开主页
  function openHome() {
    api.openTabLayout({
      name: "home",
      url: "widget://html/home/home.html",
      slidBackEnabled: false,
    });
  }

  /**
   * 打开选择职称页面
   * @param {Boolean} isFirst 是否首次打开
   */
  function openProfession(isFirst) {
    var isFirst = typeof isFirst === "boolean" ? isFirst : false;

    // 首次打开，关闭导航栏返回以及IOS滑动返回
    api.openTabLayout({
      name: "profession",
      url: "widget://html/home/profession.html",
      title: "请选择你的学习意向",
      navigationBar: {
        hideBackButton: isFirst,
      },
      pageParam: {
        isFirst: isFirst,
      },
      slidBackEnabled: !isFirst,
    });
  }

  // 打开启动引导页
  function openGuide() {
    api.openTabLayout({
      name: "guide",
      url: "widget://html/guide/guide.html",
      slidBackEnabled: false,
    });
  }

  // 打开聊天页面
  function openChat(targetId, type, title) {
    api.openFrame({
      name: "chatFrame",
      url: "widget://html/class/chat.html",
      rect: {
        x: 0,
        y: 0,
        w: "auto",
        h: "auto",
      },
      pageParam: {
        targetId: targetId,
        type: type,
        title: title,
      },
    });
  }

  // 打开班级服务介绍
  function openClassIntro() {
    api.openTabLayout({
      name: "classIntro",
      title: "班级服务",
      url: "https://vip.zhuokao360.com/app/html/class-intro.html",
      navigationBar: {
        background: "#FC9C4B",
        color: "#fff",
      },
    });
  }

  // 打开预约私教
  function openReserve() {
    if (!isLogin()) {
      openDialog("login", "遇到不解的问题，随时预约老师，来一堂属于自己的专属课堂");
      return;
    }

    // if (!hasClassService()) {
    //   openClassIntro();
    //   return;
    // }

    api.openTabLayout({
      name: "reserve",
      url: "https://vip.zhuokao360.com/app/html/reserve/",
      // url: "http://192.168.191.1:5501/app/html/reserve/index.html",
      title: "预约私教",
      navigationBar: {},
    });
  }

  // 打开联系我们
  function openContact() {
    api.openTabLayout({
      name: "consult",
      title: "联系老师",
      url: "https://vip.zhuokao360.com/app/html/consult.html",
      navigationBar: {},
    });
  }

  /**
   * 打开会话
   * @param {String} type 类型：auth权限，login登录
   * @param {String} content 提示内容
   * @param {String} imgDesc 图片描述
   */
  function openDialog(type, content, imgDesc) {
    api.openFrame({
      name: "dialog",
      url: "widget://html/dialog.html",
      rect: {
        x: 0,
        y: 0,
        w: "auto",
        h: "auto",
      },
      bgColor: "rgba(0, 0, 0, 0.6)",
      pageParam: {
        type: type,
        content: content,
        imgDesc: imgDesc,
      },
    });
  }

  // 进入直播间
  function enterLive(title, liveDetailId) {
    webview("https://cj.tibaitong.com/free/live?liveDetailId=" + liveDetailId, title);
  }

  // 观看直播回放
  function watchReplay(title, replayUrl) {
    if (!replayUrl) {
      zk.toast("小主不要着急，正在生成回放中~");
      return;
    }

    webview(replayUrl, title);
  }

  // 打开用户协议
  function openUserAgreement() {
    webview("https://vip.zhuokao360.com/terms/userAgreement/zkwx.html", "用户协议");
  }

  // 打开课程协议
  function openCourseAgreement() {
    var userId = getUserId();
    webview("https://cj.tibaitong.com/notice/relearn?userId=" + userId, "课程协议");
  }

  // 打开隐私政策
  function openPrivacyPolicy() {
    webview("https://vip.zhuokao360.com/terms/privacyPolicy/zkwx.html", "隐私政策");
  }

  // 打开 APP备案编号
  function openAppBeiAn() {
    webview("https://vip.zhuokao360.com/terms/BeiAn/zkwx.html", "APP备案编号");
  }

  // 退出APP
  function exitApp() {
    api.closeWidget();
  }

  window.zk = {
    storage: storage,
    getToken: getToken,
    isLogin: isLogin,
    getUserId: getUserId,
    getUnionid: getUnionid,
    setProfessionId: setProfessionId,
    getProfessionId: getProfessionId,
    setProfessionName: setProfessionName,
    getProfessionName: getProfessionName,
    setCourseId: setCourseId,
    getCourseId: getCourseId,
    getPhoneNumber: getPhoneNumber,
    setNickname: setNickname,
    getNickname: getNickname,
    setSignature: setSignature,
    getSignature: getSignature,
    setAvatar: setAvatar,
    getAvatar: getAvatar,
    setKeyStoreMap:setKeyStoreMap,
    getKeyStoreMap:getKeyStoreMap,
    saveUserInfo: saveUserInfo,
    setHasService: setHasService,
    getHasService: getHasService,
    isFirstLaunch: isFirstLaunch,
    setNonFirstLaunch: setNonFirstLaunch,
    setRongToken: setRongToken,
    getRongToken: getRongToken,
    hasClassService: hasClassService,
    request: request,
    loginSuccess: loginSuccess,
    loginExpired: loginExpired,
    exit: exit,
    confirmPermission: confirmPermission,
    showLoading: showLoading,
    hideLoading: hideLoading,
    toast: toast,
    log: log,
    webview: webview,
    formatFileSize: formatFileSize,
    clearAppCache: clearAppCache,
    openBrowser: openBrowser,
    openWeChat: openWeChat,
    openLogin: openLogin,
    openHome: openHome,
    openProfession: openProfession,
    openGuide: openGuide,
    openChat: openChat,
    openClassIntro: openClassIntro,
    openReserve: openReserve,
    openContact: openContact,
    openDialog: openDialog,
    enterLive: enterLive,
    watchReplay: watchReplay,
    openUserAgreement: openUserAgreement,
    openCourseAgreement: openCourseAgreement,
    openPrivacyPolicy: openPrivacyPolicy,
    openAppBeiAn: openAppBeiAn,
    exitApp: exitApp,
    closeToHome: closeToHome,
  };
})(window);

/***************************************************
 *                    Prototype                       *
 ***************************************************/

/**
 * Array.prototype.remove()
 * 删除数组指定的某个元素
 */
if (!Array.prototype.remove) {
  Array.prototype.remove = function (val) {
    var index = this.indexOf(val);
    if (index > -1) {
      this.splice(index, 1);
    }
  };
}

/**
 * Array.prototype.find()
 * https://tc39.github.io/ecma262/#sec-array.prototype.find
 */
if (!Array.prototype.find) {
  Object.defineProperty(Array.prototype, "find", {
    value: function (predicate) {
      // 1. Let O be ? ToObject(this value).
      if (this == null) {
        throw new TypeError('"this" is null or not defined');
      }

      var o = Object(this);

      // 2. Let len be ? ToLength(? Get(O, "length")).
      var len = o.length >>> 0;

      // 3. If IsCallable(predicate) is false, throw a TypeError exception.
      if (typeof predicate !== "function") {
        throw new TypeError("predicate must be a function");
      }

      // 4. If thisArg was supplied, let T be thisArg; else let T be undefined.
      var thisArg = arguments[1];

      // 5. Let k be 0.
      var k = 0;

      // 6. Repeat, while k < len
      while (k < len) {
        // a. Let Pk be ! ToString(k).
        // b. Let kValue be ? Get(O, Pk).
        // c. Let testResult be ToBoolean(? Call(predicate, T, « kValue, k, O »)).
        // d. If testResult is true, return kValue.
        var kValue = o[k];
        if (predicate.call(thisArg, kValue, k, o)) {
          return kValue;
        }
        // e. Increase k by 1.
        k++;
      }

      // 7. Return undefined.
      return undefined;
    },
  });
}

/**
 * Array.prototype.findIndex
 * https://tc39.github.io/ecma262/#sec-array.prototype.findIndex
 */
if (!Array.prototype.findIndex) {
  Object.defineProperty(Array.prototype, "findIndex", {
    value: function (predicate) {
      // 1. Let O be ? ToObject(this value).
      if (this == null) {
        throw new TypeError('"this" is null or not defined');
      }

      var o = Object(this);

      // 2. Let len be ? ToLength(? Get(O, "length")).
      var len = o.length >>> 0;

      // 3. If IsCallable(predicate) is false, throw a TypeError exception.
      if (typeof predicate !== "function") {
        throw new TypeError("predicate must be a function");
      }

      // 4. If thisArg was supplied, let T be thisArg; else let T be undefined.
      var thisArg = arguments[1];

      // 5. Let k be 0.
      var k = 0;

      // 6. Repeat, while k < len
      while (k < len) {
        // a. Let Pk be ! ToString(k).
        // b. Let kValue be ? Get(O, Pk).
        // c. Let testResult be ToBoolean(? Call(predicate, T, « kValue, k, O »)).
        // d. If testResult is true, return k.
        var kValue = o[k];
        if (predicate.call(thisArg, kValue, k, o)) {
          return k;
        }
        // e. Increase k by 1.
        k++;
      }

      // 7. Return -1.
      return -1;
    },
  });
}

/**
 * Array.prototype.includes()
 * https://tc39.github.io/ecma262/#sec-array.prototype.includes
 */
if (!Array.prototype.includes) {
  Object.defineProperty(Array.prototype, "includes", {
    value: function (valueToFind, fromIndex) {
      if (this == null) {
        throw new TypeError('"this" is null or not defined');
      }

      // 1. Let O be ? ToObject(this value).
      var o = Object(this);

      // 2. Let len be ? ToLength(? Get(O, "length")).
      var len = o.length >>> 0;

      // 3. If len is 0, return false.
      if (len === 0) {
        return false;
      }

      // 4. Let n be ? ToInteger(fromIndex).
      //    (If fromIndex is undefined, this step produces the value 0.)
      var n = fromIndex | 0;

      // 5. If n ≥ 0, then
      //  a. Let k be n.
      // 6. Else n < 0,
      //  a. Let k be len + n.
      //  b. If k < 0, let k be 0.
      var k = Math.max(n >= 0 ? n : len - Math.abs(n), 0);

      function sameValueZero(x, y) {
        return x === y || (typeof x === "number" && typeof y === "number" && isNaN(x) && isNaN(y));
      }

      // 7. Repeat, while k < len
      while (k < len) {
        // a. Let elementK be the result of ? Get(O, ! ToString(k)).
        // b. If SameValueZero(valueToFind, elementK) is true, return true.
        if (sameValueZero(o[k], valueToFind)) {
          return true;
        }
        // c. Increase k by 1.
        k++;
      }

      // 8. Return false
      return false;
    },
  });
}

/**
 * Object.assign()
 * https://developer.mozilla.org/zh-CN/docs/Web/JavaScript/Reference/Global_Objects/Object/assign
 */
if (typeof Object.assign !== "function") {
  // Must be writable: true, enumerable: false, configurable: true
  Object.defineProperty(Object, "assign", {
    value: function assign(target, varArgs) {
      // .length of function is 2
      "use strict";
      if (target === null || target === undefined) {
        throw new TypeError("Cannot convert undefined or null to object");
      }

      var to = Object(target);

      for (var index = 1; index < arguments.length; index++) {
        var nextSource = arguments[index];

        if (nextSource !== null && nextSource !== undefined) {
          for (var nextKey in nextSource) {
            // Avoid bugs when hasOwnProperty is shadowed
            if (Object.prototype.hasOwnProperty.call(nextSource, nextKey)) {
              to[nextKey] = nextSource[nextKey];
            }
          }
        }
      }
      return to;
    },
    writable: true,
    configurable: true,
  });
}
